@@ -518,7 +518,7 @@ test -x $repomanager_prog && repomanager_entry=$(entry \
 
 which backlight-brightness &>/dev/null && [ -n "$(ls /sys/class/backlight 2>/dev/null)" ] \
     && backlight_entry=$(entry \
-    $ICONS2/background-brightness.png \
+    $ICONS2/backlight-brightness.png \
     "desktop-defaults-run -t backlight-brightness &" \
     $"Backlight Brightness")
 
